#!/bin/sh

# This helper script will handle deploying a sns topic
set -e

source /scripts/utils.sh
source /scripts/terraform.sh

if [ -z "${topicName}" ]; then
  echo "Must set env topicName"
  exit 1
fi

run_cmd cp /etc/config/access-policy.json /terraform/

check_access ${appsNamespace} configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars

echo "iam_policy_prefix = \"${externalNamingPrefix}\"" >> ${tfAdditionalVarsFile}

terraform_init
terraform_plan
terraform_apply
terraform_output

print_header "Dump output to ConfigMap"
arnConfigMapName=${namingPrefix}-arn
terraform_get sns_topic_arn arnValue
terraform_get sns_topic_name topicName
terraform_get publisher_policy publisherPolicy

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  topicName: ${topicName}
  ARN: ${arnValue}
  PublisherPolicy: ${publisherPolicy}

EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

cprint "$0 done "
